import pytest
import requests
from typing import List
from pydantic import parse_obj_as
from bkw_python import BkwApi, BkwException
from bkw_python.data_models import Case

def test_run_claims_register_basic(requests_mock):
    requests_mock.get(
        "https://api.bk.watch/api/2022-08-01?username=test&password=password&PROTOCOL=JSON&OPERATION=RunClaimsRegister&district=UT&extendedCaseNumber=2%3A22-bk-24863", 
        json={'case': {'id': 'case-9f8d6d58', 'district': 'UT', 'division': 'Salt Lake City', 'county': 'Utah', 'caseNumber': '2:22-bk-24863', 'title': 'Lisa Eilene Moore', 'chapter': 7, 'dateEntered': '2022-12-13', 'dateFiled': '2022-12-13', 'lastDateToFileClaims': '2023-04-24', 'closed': False, 'filingFeeStatus': 'Paid', 'assets': True, 'voluntary': True, 'debtorType': 'INDIVIDUAL', 'debtType': 'CONSUMER', 'claims': [{'id': 'claim-2f6667f2', 'claimNumber': 1, 'creditor': {'id': 'creditor-286396a3', 'name': 'CREDIT FIRST NA', 'creditorNumber': 12151968, 'address': {'organization': 'CREDIT FIRST NA', 'street1': 'PO BOX 818011', 'city': 'CLEVELAND', 'state': 'OHIO', 'zip': '44181', 'zip4': '8011'}}, 'dateFiled': '2023-01-30', 'totalClaimed': '1132.43', 'filings': [{'id': 'filing-9cf29dd8', 'type': 'PROOF', 'dateFiled': '2023-01-30', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #1 filed by CREDIT FIRST NA, Amount claimed: $1132.43 (Diaz, Maritza)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32789344&claim_num=1-1&magic_num=MAGIC'}]}, {'id': 'claim-9ba38ee9', 'claimNumber': 2, 'creditor': {'id': 'creditor-2f679d92', 'name': 'Citibank, N.A.', 'creditorNumber': 12152630, 'address': {'firstName': 'N.A.', 'lastName': 'Citibank', 'street1': '5800 S Corporate Pl', 'city': 'Sioux Falls', 'state': 'SD', 'zip': '57108', 'zip4': '5027'}}, 'dateFiled': '2023-01-31', 'totalClaimed': '482.11', 'filings': [{'id': 'filing-5154a697', 'type': 'PROOF', 'dateFiled': '2023-01-31', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #2 filed by Citibank, N.A., Amount claimed: $482.11 (Wiens, Gwendolyn)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32794193&claim_num=2-1&magic_num=MAGIC'}]}, {'id': 'claim-d0c7dc9d', 'claimNumber': 3, 'creditor': {'id': 'creditor-0a5358c1', 'name': 'Quantum3 Group LLC as agent for', 'creditorNumber': 12153368, 'address': {'organization': 'Quantum3 Group LLC as agent for\nGenesis FS Card Services Inc', 'street1': 'PO Box 788', 'city': 'Kirkland', 'state': 'WA', 'zip': '98083', 'zip4': '0788'}}, 'dateFiled': '2023-02-01', 'totalClaimed': '270.08', 'filings': [{'id': 'filing-2b6301a3', 'type': 'PROOF', 'dateFiled': '2023-02-01', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #3 filed by Quantum3 Group LLC as agent for, Amount claimed: $270.08 (White, Jessi)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32797179&claim_num=3-1&magic_num=MAGIC'}]}, {'id': 'claim-0a52a3a1', 'claimNumber': 4, 'creditor': {'id': 'creditor-833f9a10', 'name': 'Capital One N.A.', 'creditorNumber': 12154110, 'address': {'organization': 'Capital One N.A.\nby American InfoSource as agent', 'street1': 'PO Box 71083', 'city': 'Charlotte', 'state': 'NC', 'zip': '28272', 'zip4': '1083'}}, 'dateFiled': '2023-02-03', 'totalClaimed': '306.44', 'filings': [{'id': 'filing-64b4fdd5', 'type': 'PROOF', 'dateFiled': '2023-02-03', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #4 filed by Capital One N.A., Amount claimed: $306.44 (Boswell, Ashley)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32801657&claim_num=4-1&magic_num=MAGIC'}]}, {'id': 'claim-52552677', 'claimNumber': 5, 'creditor': {'id': 'creditor-525420b7', 'name': 'Bank of America, N.A.', 'creditorNumber': 12158541, 'address': {'organization': 'Bank of America, N.A.', 'street1': 'PO Box 673033', 'city': 'Dallas', 'state': 'TX', 'zip': '75267', 'zip4': '3033'}}, 'dateFiled': '2023-02-15', 'securedClaimed': '0.00', 'priorityClaimed': '0.00', 'totalClaimed': '531.22', 'filings': [{'id': 'filing-64b40785', 'type': 'PROOF', 'dateFiled': '2023-02-15', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #5 filed by Bank of America, N.A., Amount claimed: $531.22 (Allred, James)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32825861&claim_num=5-1&magic_num=MAGIC'}]}]}, 'status': 0, 'message': 'Success'}
    )
    testing_session = BkwApi(username='test', password='password')
    case = testing_session.run_claims_register(district='UT', extendedCaseNumber='2:22-bk-24863')
    assert case.id == 'case-9f8d6d58'

def test_run_claims_register_cache(requests_mock):
    requests_mock.get(
        "https://api.bk.watch/api/2022-08-01?username=test&password=password&PROTOCOL=JSON&OPERATION=RunClaimsRegister&district=UT&extendedCaseNumber=2%3A22-bk-24863&cache=true", 
        json={'case': {'id': 'case-9f8d6d58', 'district': 'UT', 'division': 'Salt Lake City', 'county': 'Utah', 'caseNumber': '2:22-bk-24863', 'title': 'Lisa Eilene Moore', 'chapter': 7, 'dateEntered': '2022-12-13', 'dateFiled': '2022-12-13', 'closed': False, 'filingFeeStatus': 'Paid', 'assets': True, 'voluntary': True, 'debtorType': 'INDIVIDUAL', 'debtType': 'CONSUMER', 'claims': [{'id': 'claim-2f6667f2', 'claimNumber': 1, 'creditor': {'id': 'creditor-286396a3', 'name': 'CREDIT FIRST NA', 'creditorNumber': 12151968, 'address': {'organization': 'CREDIT FIRST NA', 'street1': 'PO BOX 818011', 'city': 'CLEVELAND', 'state': 'OHIO', 'zip': '44181', 'zip4': '8011'}}, 'dateFiled': '2023-01-30', 'totalClaimed': '1132.43', 'filings': [{'id': 'filing-9cf29dd8', 'type': 'PROOF', 'dateFiled': '2023-01-30', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #1 filed by CREDIT FIRST NA, Amount claimed: $1132.43 (Diaz, Maritza)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32789344&claim_num=1-1&magic_num=MAGIC'}]}, {'id': 'claim-9ba38ee9', 'claimNumber': 2, 'creditor': {'id': 'creditor-2f679d92', 'name': 'Citibank, N.A.', 'creditorNumber': 12152630, 'address': {'firstName': 'N.A.', 'lastName': 'Citibank', 'street1': '5800 S Corporate Pl', 'city': 'Sioux Falls', 'state': 'SD', 'zip': '57108', 'zip4': '5027'}}, 'dateFiled': '2023-01-31', 'totalClaimed': '482.11', 'filings': [{'id': 'filing-5154a697', 'type': 'PROOF', 'dateFiled': '2023-01-31', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #2 filed by Citibank, N.A., Amount claimed: $482.11 (Wiens, Gwendolyn)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32794193&claim_num=2-1&magic_num=MAGIC'}]}, {'id': 'claim-d0c7dc9d', 'claimNumber': 3, 'creditor': {'id': 'creditor-0a5358c1', 'name': 'Quantum3 Group LLC as agent for', 'creditorNumber': 12153368, 'address': {'organization': 'Quantum3 Group LLC as agent for\nGenesis FS Card Services Inc', 'street1': 'PO Box 788', 'city': 'Kirkland', 'state': 'WA', 'zip': '98083', 'zip4': '0788'}}, 'dateFiled': '2023-02-01', 'totalClaimed': '270.08', 'filings': [{'id': 'filing-2b6301a3', 'type': 'PROOF', 'dateFiled': '2023-02-01', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #3 filed by Quantum3 Group LLC as agent for, Amount claimed: $270.08 (White, Jessi)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32797179&claim_num=3-1&magic_num=MAGIC'}]}, {'id': 'claim-0a52a3a1', 'claimNumber': 4, 'creditor': {'id': 'creditor-833f9a10', 'name': 'Capital One N.A.', 'creditorNumber': 12154110, 'address': {'organization': 'Capital One N.A.\nby American InfoSource as agent', 'street1': 'PO Box 71083', 'city': 'Charlotte', 'state': 'NC', 'zip': '28272', 'zip4': '1083'}}, 'dateFiled': '2023-02-03', 'totalClaimed': '306.44', 'filings': [{'id': 'filing-64b4fdd5', 'type': 'PROOF', 'dateFiled': '2023-02-03', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #4 filed by Capital One N.A., Amount claimed: $306.44 (Boswell, Ashley)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32801657&claim_num=4-1&magic_num=MAGIC'}]}, {'id': 'claim-52552677', 'claimNumber': 5, 'creditor': {'id': 'creditor-525420b7', 'name': 'Bank of America, N.A.', 'creditorNumber': 12158541, 'address': {'organization': 'Bank of America, N.A.', 'street1': 'PO Box 673033', 'city': 'Dallas', 'state': 'TX', 'zip': '75267', 'zip4': '3033'}}, 'dateFiled': '2023-02-15', 'securedClaimed': '0.00', 'priorityClaimed': '0.00', 'totalClaimed': '531.22', 'filings': [{'id': 'filing-64b40785', 'type': 'PROOF', 'dateFiled': '2023-02-15', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #5 filed by Bank of America, N.A., Amount claimed: $531.22 (Allred, James)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32825861&claim_num=5-1&magic_num=MAGIC'}]}]}, 'status': 0, 'message': 'Success'}
    )
    testing_session = BkwApi(username='test', password='password')
    case = testing_session.run_claims_register(district='UT', extendedCaseNumber='2:22-bk-24863', cache=True)
    assert case.id == 'case-9f8d6d58'

def test_run_claims_register_no_cache(requests_mock):
    requests_mock.get(
        "https://api.bk.watch/api/2022-08-01?username=test&password=password&PROTOCOL=JSON&OPERATION=RunClaimsRegister&district=UT&extendedCaseNumber=2%3A22-bk-24863&cache=false", 
        json={'case': {'id': 'case-9f8d6d58', 'district': 'UT', 'division': 'Salt Lake City', 'county': 'Utah', 'caseNumber': '2:22-bk-24863', 'title': 'Lisa Eilene Moore', 'chapter': 7, 'dateEntered': '2022-12-13', 'dateFiled': '2022-12-13', 'closed': False, 'filingFeeStatus': 'Paid', 'assets': True, 'voluntary': True, 'debtorType': 'INDIVIDUAL', 'debtType': 'CONSUMER', 'claims': [{'id': 'claim-2f6667f2', 'claimNumber': 1, 'creditor': {'id': 'creditor-286396a3', 'name': 'CREDIT FIRST NA', 'creditorNumber': 12151968, 'address': {'organization': 'CREDIT FIRST NA', 'street1': 'PO BOX 818011', 'city': 'CLEVELAND', 'state': 'OHIO', 'zip': '44181', 'zip4': '8011'}}, 'dateFiled': '2023-01-30', 'totalClaimed': '1132.43', 'filings': [{'id': 'filing-9cf29dd8', 'type': 'PROOF', 'dateFiled': '2023-01-30', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #1 filed by CREDIT FIRST NA, Amount claimed: $1132.43 (Diaz, Maritza)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32789344&claim_num=1-1&magic_num=MAGIC'}]}, {'id': 'claim-9ba38ee9', 'claimNumber': 2, 'creditor': {'id': 'creditor-2f679d92', 'name': 'Citibank, N.A.', 'creditorNumber': 12152630, 'address': {'firstName': 'N.A.', 'lastName': 'Citibank', 'street1': '5800 S Corporate Pl', 'city': 'Sioux Falls', 'state': 'SD', 'zip': '57108', 'zip4': '5027'}}, 'dateFiled': '2023-01-31', 'totalClaimed': '482.11', 'filings': [{'id': 'filing-5154a697', 'type': 'PROOF', 'dateFiled': '2023-01-31', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #2 filed by Citibank, N.A., Amount claimed: $482.11 (Wiens, Gwendolyn)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32794193&claim_num=2-1&magic_num=MAGIC'}]}, {'id': 'claim-d0c7dc9d', 'claimNumber': 3, 'creditor': {'id': 'creditor-0a5358c1', 'name': 'Quantum3 Group LLC as agent for', 'creditorNumber': 12153368, 'address': {'organization': 'Quantum3 Group LLC as agent for\nGenesis FS Card Services Inc', 'street1': 'PO Box 788', 'city': 'Kirkland', 'state': 'WA', 'zip': '98083', 'zip4': '0788'}}, 'dateFiled': '2023-02-01', 'totalClaimed': '270.08', 'filings': [{'id': 'filing-2b6301a3', 'type': 'PROOF', 'dateFiled': '2023-02-01', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #3 filed by Quantum3 Group LLC as agent for, Amount claimed: $270.08 (White, Jessi)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32797179&claim_num=3-1&magic_num=MAGIC'}]}, {'id': 'claim-0a52a3a1', 'claimNumber': 4, 'creditor': {'id': 'creditor-833f9a10', 'name': 'Capital One N.A.', 'creditorNumber': 12154110, 'address': {'organization': 'Capital One N.A.\nby American InfoSource as agent', 'street1': 'PO Box 71083', 'city': 'Charlotte', 'state': 'NC', 'zip': '28272', 'zip4': '1083'}}, 'dateFiled': '2023-02-03', 'totalClaimed': '306.44', 'filings': [{'id': 'filing-64b4fdd5', 'type': 'PROOF', 'dateFiled': '2023-02-03', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #4 filed by Capital One N.A., Amount claimed: $306.44 (Boswell, Ashley)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32801657&claim_num=4-1&magic_num=MAGIC'}]}, {'id': 'claim-52552677', 'claimNumber': 5, 'creditor': {'id': 'creditor-525420b7', 'name': 'Bank of America, N.A.', 'creditorNumber': 12158541, 'address': {'organization': 'Bank of America, N.A.', 'street1': 'PO Box 673033', 'city': 'Dallas', 'state': 'TX', 'zip': '75267', 'zip4': '3033'}}, 'dateFiled': '2023-02-15', 'securedClaimed': '0.00', 'priorityClaimed': '0.00', 'totalClaimed': '531.22', 'filings': [{'id': 'filing-64b40785', 'type': 'PROOF', 'dateFiled': '2023-02-15', 'itemNumber': 1, 'title': 'Proof of Claim', 'text': 'Claim #5 filed by Bank of America, N.A., Amount claimed: $531.22 (Allred, James)', 'url': 'https://ecf.utb.uscourts.gov/cgi-bin/show_doc.pl?caseid=455293&claim_id=32825861&claim_num=5-1&magic_num=MAGIC'}]}]}, 'status': 0, 'message': 'Success'}
    )
    testing_session = BkwApi(username='test', password='password')
    case = testing_session.run_claims_register(district='UT', extendedCaseNumber='2:22-bk-24863', cache=False)
    assert case.id == 'case-9f8d6d58'
    
def test_run_claims_register_invalid_case(requests_mock):
    requests_mock.get(
        "https://api.bk.watch/api/2022-08-01?username=test&password=password&PROTOCOL=JSON&OPERATION=RunClaimsRegister&district=UT&extendedCaseNumber=22-24863", 
        json={'status': 3, 'message': 'Invalid extended case number: 22-24863'}
    )
    testing_session = BkwApi(username='test', password='password')
    with pytest.raises(BkwException) as failure_message:
        case = testing_session.run_claims_register(district='UT', extendedCaseNumber='22-24863')
    assert "Invalid extended case number: 22-24863" in str(failure_message.value)